@@ -689,26 +689,26 @@ void drawline(long i)
         putc('+', outfile);
       trif = false;
       if (!q->tip) {
-        for (j = 1; j <= n - 7; j++)
+        for (j = 1; j <= n - 8; j++)
           putc('-', outfile);
         if (noroot && (root->next->next->next == root) &&
             (((root->next->back == q) && root->next->next->back->tip)
              || ((root->next->next->back == q) && root->next->back->tip)))
-          fprintf(outfile, "------|");
+          fprintf(outfile, "-------|");
         else {
           if (!strict) {   /* write number of times seen */
             if (q->deltav >= 10000)
-              fprintf(outfile, "%5.0f-|", (double)q->deltav);
+              fprintf(outfile, "-%5.0f-|", (double)q->deltav);
             else if (q->deltav >= 1000)
-              fprintf(outfile, "-%4.0f-|", (double)q->deltav);
+              fprintf(outfile, "--%4.0f-|", (double)q->deltav);
             else if (q->deltav >= 100)
-              fprintf(outfile, "%5.1f-|", (double)q->deltav);
+              fprintf(outfile, "-%5.1f-|", (double)q->deltav);
             else if (q->deltav >= 10)
-              fprintf(outfile, "-%4.1f-|", (double)q->deltav);
+              fprintf(outfile, "--%4.1f-|", (double)q->deltav);
             else
-              fprintf(outfile, "-%4.2f-|", (double)q->deltav);
+              fprintf(outfile, "--%4.2f-|", (double)q->deltav);
           } else
-            fprintf(outfile, "------|");
+            fprintf(outfile, "-------|");
         }
         extra = true;
         trif = true;
