@@ -1,7 +1,7 @@
 #include "phylip.h"
 #include "cons.h"
 
-/* version 3.6. (c) Copyright 1993-2004 by the University of Washington.
+/* version 3.6. (c) Copyright 1993-2008 by the University of Washington.
    Written by Joseph Felsenstein, Hisashi Horino,
    Akiko Fuseki, Dan Fineman, Sean Lamont, and Andrew Keeffe.
    Permission is granted
@@ -318,10 +318,7 @@ void treeout(node *p)
       } else if (x >= 10.0) {
           fprintf(outtree, ":%4.1f", x); 
           col += 3;
-        } else if (x >= 0.99) {
-            fprintf(outtree, ":%3.1f", x);
-            col += 2;
-          } else {
+        } else if (x >= 1.00) {
             fprintf(outtree, ":%4.2f", x); 
             col += 3;
           }
@@ -334,9 +331,9 @@ int main(int argc, Char *argv[])
 {  
   /* Local variables added by Dan F. */
   pattern_elm  ***pattern_array;
-  double *timesseen_changes = NULL;
   long trees_in = 0;
   long i, j;
+  long tip_count = 0;
   node *p, *q;
 
 #ifdef MAC
@@ -363,9 +360,13 @@ int main(int argc, Char *argv[])
     fprintf(outfile, "Species in order: \n\n");
 
   trees_in = countsemic(&intree);
+  countcomma(&intree,&tip_count);
+  tip_count++; /* countcomma does a raw comma count, tips is one greater */
+
+
 
   /* Read the tree file and put together grouping, order, and timesseen */
-  read_groups (&pattern_array, timesseen_changes, trees_in, trees_in, intree);
+  read_groups (&pattern_array, trees_in, tip_count, intree);
   /* Compute the consensus tree. */
   putc('\n', outfile);
   nodep      = (pointarray)Malloc(2*(1+spp)*sizeof(node *));
