@@ -317,10 +317,6 @@ void getoptions()
       matrix_flags = MAT_LOWER | MAT_HUMAN;
   }
 
-#ifdef DEBUG
-  fprintf(stderr, "Matrix type: %x %s\n", matrix_flags);
-#endif /* DEBUG */
-
   if (gama || invar) {
     loopcount = 0;
     do {
