@@ -2135,9 +2135,9 @@ static void maketree()
   
   if (jumb == njumble) {
     if (progress) {
-      printf("\nOutput written to file \"%s\"\n\n", outfilename);
+      printf("\nOutput written to file \"%s\"\n", outfilename);
       if (trout)
-        printf("Tree also written onto file \"%s\"\n\n", outtreename);
+        printf("\nTree also written onto file \"%s\"\n", outtreename);
     }
     free(contribution);
     freex(nonodes, curtree.nodep);
@@ -2220,7 +2220,7 @@ int main(int argc, Char *argv[])
   fixmacfile(outfilename);
   fixmacfile(outtreename);
 #endif
-  printf("Done.\n\n");
+  printf("\nDone.\n\n");
 #ifdef WIN32
   phyRestoreConsoleAttributes();
 #endif
