@@ -327,6 +327,7 @@ void allocrest()
   guess = (Char *)Malloc(chars*sizeof(Char));
   zeroanc = (bitptr)Malloc(words*sizeof(long));
   oneanc = (bitptr)Malloc(words*sizeof(long));
+  steps = (bitptr)Malloc(words*sizeof(long));
 }  /* allocrest */
 
 
@@ -428,6 +429,7 @@ void dollop_count(node *p, steptr numsone, steptr numszero)
       j++;
     }
     if (((1L << l) & steps[j - 1]) != 0) {
+      assert(j <= words);   /* checking array indexing */
       if (((1L << l) & zeroanc[j - 1]) != 0)
         numszero[i] += weight[i];
       else
@@ -752,7 +754,6 @@ void maketree()
   double gotlike;
   node *item, *nufork, *dummy, *p;
 
-  steps = (bitptr)Malloc(words*sizeof(long));
   fullset = (1L << (bits + 1)) - (1L << 1);
   if (!usertree) {
     for (i = 1; i <= (spp); i++)
@@ -920,7 +921,6 @@ void maketree()
       if (trout)
         printf("Trees also written onto file \"%s\"\n\n", outtreename);
     }
-    free(steps);
     if (ancseq)
       freegarbage(&garbage);
   }
@@ -982,6 +982,9 @@ int main(int argc, Char *argv[])
     for (jumb = 1; jumb <= njumble; jumb++)
       maketree();
   }
+  /* this would be an appropriate place to deallocate memory, including these items:
+  free(steps);
+  */
   FClose(infile);
   FClose(outfile);
   FClose(outtree);
