@@ -1059,9 +1059,9 @@ void maketree()
   }
   if (jumb == njumble) {
     if (progress) {
-      printf("\nOutput written to file \"%s\"\n\n", outfilename);
+      printf("\nOutput written to file \"%s\"\n", outfilename);
       if (trout)
-        printf("Trees also written onto file \"%s\"\n", outtreename);
+        printf("\nTrees also written onto file \"%s\"\n", outtreename);
       putchar('\n');
     }
   }
