@@ -460,7 +460,7 @@ void initseed(long *inseed, long *inseed0, longer seed)
   assert(inseed0);
   loopcount = 0;
   for (;;) {
-    printf("Random number seed (must be odd)?\n");
+    printf("\nRandom number seed (must be odd)?\n");
     fflush(stdout);
     if (scanf("%ld%*[^\n]", inseed) == 1) {
       getchar();
@@ -2246,14 +2246,6 @@ void hookup(node *p, node *q)
 { /* hook together two nodes */
   assert(p != NULL);
   assert(q != NULL);
-#ifdef DEBUG
-  if (p->back != NULL || q->back != NULL)
-    printf("warning: attempt to hookup already-connected nodes\n");
-#else
-  assert(p->back == NULL);
-  assert(q->back == NULL);
-#endif
-  
   p->back = q;
   q->back = p;
 }  /* hookup */
@@ -2514,9 +2506,6 @@ void treeread (FILE *treefile, node **root, pointarray treenode,
   long parens = 0;
   long ntips = 0;
 
-#ifdef DEBUG
-  debugtree2(nodep, maxnodes, outtree);
-#endif
   (*goteof) = false;
   (*nextnode) = spp;
 
@@ -3028,7 +3017,7 @@ void output_matrix_d(FILE *fp, double **matrix,
   unsigned long i;
   unsigned long cstart, cend;
   unsigned long textwidth = OUTPUT_TEXTWIDTH;
-  const int     gutter = 1;
+  const unsigned int     gutter = 1;
   boolean       do_block;
   boolean       lower_triangle;
   boolean       border;
